/*
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import Foundation

class ImportedFirmwareImage: NSObject, NSCoding
{
    // MARK: - Member variables
    var firmwareImageArray: Data!
    var filename: String!
    var persist: Bool?
    
    // MARK: Types
    struct PropertyKey
    {
        static let imageArray = "imageArray"
        static let filename = "filename"
    }
    
    init(firmware: Data, filename: String, persist: Bool = true)
    {
        super.init()
        
        self.firmwareImageArray = firmware
        self.filename = filename
        self.persist = persist
    }
    
    //MARK: NSCoding
    func encode(with aCoder: NSCoder)
    {
        aCoder.encode(firmwareImageArray, forKey: PropertyKey.imageArray)
        aCoder.encode(filename, forKey: PropertyKey.filename)
    }
    
    required convenience init?(coder aDecoder: NSCoder)
    {
        let decodedImage = aDecoder.decodeObject(forKey: PropertyKey.imageArray) as! Data
        let decodedFilename = aDecoder.decodeObject(forKey: PropertyKey.filename) as! String
        
        self.init(firmware: decodedImage, filename: decodedFilename)
    }
    
    // MARK: - Functions
    func getTableLabel() -> String
    {
        return "\(self.filename!) - \(self.firmwareImageArray.count)bytes"
    }
    
    // MARK: Archiving Paths:
    static let DocumentsDirectory = FileManager().urls(for: .documentDirectory, in: .userDomainMask).first!
    static let ArchiveURL = DocumentsDirectory.appendingPathComponent("firmwareImage")
    
}
